@@ -390,7 +390,6 @@ end_element_handler (GMarkupParseContext *context,
 			    GError **error)
 {
 	ParseInfo *info = (ParseInfo *)user_data;
-	GnomeVFSURI *uri;
 
 	switch (peek_state (info)) {
 		case STATE_RECENT_ITEM:
@@ -554,9 +553,9 @@ egg_recent_model_filter (EggRecentModel *model,
 			if (egg_recent_model_group_match
 					(item, model->priv->group_filter_values))
 				pass_group_test = TRUE;
-		} else if (egg_recent_item_get_private (item))
+		} else if (egg_recent_item_get_private (item)) {
 			pass_group_test = FALSE;
-		else
+		} else
 			pass_group_test = TRUE;
 
 		/* filter by URI scheme */
@@ -574,6 +573,7 @@ egg_recent_model_filter (EggRecentModel *model,
 		} else
 			pass_scheme_test = TRUE;
 
+
 		if (pass_mime_test && pass_group_test && pass_scheme_test)
 			newlist = g_list_prepend(newlist, item);
 
@@ -905,7 +905,6 @@ egg_recent_model_finalize (GObject *object)
 
 	egg_recent_model_monitor (model, FALSE);
 
-
 	g_slist_foreach (model->priv->mime_filter_values,
 			 (GFunc) g_pattern_spec_free, NULL);
 	g_slist_free (model->priv->mime_filter_values);
